<?php
namespace Modules\Cadastros\Services;

use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;

class Ger11300PeriodicidadeService {
    private $entityManager;
    private $connection;
    private $environment;
    private $supUtilities;

    public function __construct($entityManager, $connection, $environment, $supUtilities) {
        $this->entityManager = $entityManager;
        $this->connection = $connection;
        $this->environment = $environment;
        $this->supUtilities = $supUtilities;
    }

    /**
     * Função responsável por excluir todos os
     * dias de entrega de uma periodicidade.
     * 
     * @param {String} $cdPeriEntr Código de Periodicidade.
     */
    public function deleteAllDiaEntrega($cdPeriEntr){
        try{
            $query = "DELETE FROM DIASENTR 
                    WHERE CDPERIENTR = :CDPERIENTR";

            $param = array(
                "CDPERIENTR" => $cdPeriEntr
            );

            $this->supUtilities->crud($query, $param);
        } catch (\Exception $e){
            throw $e; 
        }
    }


    /**
     * Função responsável por excluir todos os
     * dias de entrega de uma periodicidade.
     * 
     * @param {String} $cdPeriEntr Código de Periodicidade.
     * 
     * @return {Array} Array contendo resultado da consulta.
     */
    public function existsDiaEntrega($cdPeriEntr){
        try{
            $query = "SELECT COUNT(*) EXIST
                    FROM DIASENTR
                    WHERE (CDPERIENTR = :CDPERIENTR)";

            $param = array(
                "CDPERIENTR" => $cdPeriEntr
            );

            return $this->supUtilities->crud($query, $param)[0];
        } catch (\Exception $e){
            throw $e; 
        }

    }
    
    public function getDiasConsumo($row){
        try{
            $query = "SELECT 
                          *
                        FROM 
                          DIASCONSUMO
                        WHERE
                          CDPERIENTR = :P_CDPERIENTR AND
                          DIENTREGA = :P_DIENTREGA AND
                          NRORG = :P_NRORG";
            
            $params = array(
                "P_CDPERIENTR" => $row['CDPERIENTR'],
                "P_DIENTREGA"  => $row['DIENTREGA'],
                "P_NRORG"      => $this->environment->getNrorg(),
            );

            return $this->supUtilities->crud($query, $params);
        } catch (\Exception $e){
            throw $e; 
        }
    }
    
    public function insertDiaEntrega($row){
        try{
            $query = "INSERT INTO DIASENTR
                        (
                            CDPERIENTR, 
                            DIENTREGA, 
                            IDOCOR01, 
                            IDOCOR02, 
                            IDOCOR03,      
                            IDOCOR04, 
                            IDOCOR05, 
                            IDDOMPERIREC, 
                            IDSEGPERIREC,               
                            IDTERPERIREC, 
                            IDQUAPERIREC, 
                            IDQUIPERIREC, 
                            IDSEXPERIREC,
                            IDSABPERIREC,
                            NRORG
                        )
                      VALUES
                        (
                            :CDPERIENTR, 
                            :DIENTREGA, 
                            :IDOCOR01, 
                            :IDOCOR02, 
                            :IDOCOR03, 
                            :IDOCOR04, 
                            :IDOCOR05, 
                            :IDDOMPERIREC, 
                            :IDSEGPERIREC,               
                            :IDTERPERIREC, 
                            :IDQUAPERIREC, 
                            :IDQUIPERIREC, 
                            :IDSEXPERIREC,
                            :IDSABPERIREC,
                            :NRORG
                        )";
            
            $params = array(
                "CDPERIENTR"   => $row['CDPERIENTR'], 
                "DIENTREGA"    => $row['DIENTREGA'], 
                "IDOCOR01"     => $row['IDOCOR01'], 
                "IDOCOR02"     => $row['IDOCOR02'], 
                "IDOCOR03"     => $row['IDOCOR03'], 
                "IDOCOR04"     => $row['IDOCOR04'], 
                "IDOCOR05"     => $row['IDOCOR05'], 
                "IDDOMPERIREC" => $row['IDDOMPERIREC'], 
                "IDSEGPERIREC" => $row['IDSEGPERIREC'],               
                "IDTERPERIREC" => $row['IDTERPERIREC'], 
                "IDQUAPERIREC" => $row['IDQUAPERIREC'], 
                "IDQUIPERIREC" => $row['IDQUIPERIREC'], 
                "IDSEXPERIREC" => $row['IDSEXPERIREC'],
                "IDSABPERIREC" => $row['IDSABPERIREC'],
                "NRORG"       => $this->environment->getNrorg(),
            );

            $this->supUtilities->crud($query, $params);
        } catch (\Exception $e){
            throw $e; 
        }
    }
    
    public function updateDiaEntrega($row){
        try{
            $query = "UPDATE DIASENTR
                        SET
                            CDPERIENTR = :CDPERIENTR, 
                            DIENTREGA = :DIENTREGA, 
                            IDOCOR01 = :IDOCOR01, 
                            IDOCOR02 = :IDOCOR02, 
                            IDOCOR03 = :IDOCOR03,      
                            IDOCOR04 = :IDOCOR04, 
                            IDOCOR05 = :IDOCOR05, 
                            IDDOMPERIREC = :IDDOMPERIREC, 
                            IDSEGPERIREC = :IDSEGPERIREC,               
                            IDTERPERIREC = :IDTERPERIREC, 
                            IDQUAPERIREC = :IDQUAPERIREC, 
                            IDQUIPERIREC = :IDQUIPERIREC, 
                            IDSEXPERIREC = :IDSEXPERIREC,
                            IDSABPERIREC = :IDSABPERIREC
                        WHERE
                            CDPERIENTR = :CDPERIENTR AND 
                            DIENTREGA = :DIENTREGA AND
                            NRORG = :NRORG";
            
            $params = array(
                "CDPERIENTR"   => $row['CDPERIENTR'], 
                "DIENTREGA"    => $row['DIENTREGA'], 
                "IDOCOR01"     => $row['IDOCOR01'], 
                "IDOCOR02"     => $row['IDOCOR02'], 
                "IDOCOR03"     => $row['IDOCOR03'], 
                "IDOCOR04"     => $row['IDOCOR04'], 
                "IDOCOR05"     => $row['IDOCOR05'], 
                "IDDOMPERIREC" => $row['IDDOMPERIREC'], 
                "IDSEGPERIREC" => $row['IDSEGPERIREC'],               
                "IDTERPERIREC" => $row['IDTERPERIREC'], 
                "IDQUAPERIREC" => $row['IDQUAPERIREC'], 
                "IDQUIPERIREC" => $row['IDQUIPERIREC'], 
                "IDSEXPERIREC" => $row['IDSEXPERIREC'],
                "IDSABPERIREC" => $row['IDSABPERIREC'],
                "NRORG"       => $this->environment->getNrorg(),
            );

            $this->supUtilities->crud($query, $params);
        } catch (\Exception $e){
            throw $e; 
        }
    }
    
    public function insertDiasConsumo($row, $diaConsumo){
        try{
            $query = "INSERT INTO DIASCONSUMO
                        (
                            NRDIASCONSUMO,
                            CDPERIENTR,
                            DIENTREGA ,
                            DIACONSUMOINI,
                            DIACONSUMOFIN,
                            IDDIACONSINIANT,
                            IDDIACONSFINANT,
                            NRORG
                        )
                        VALUES
                        (
                            SEQ_NRDIASCONSUMO.NEXTVAL,
                            :P_CDPERIENTR,
                            :P_DIENTREGA,
                            :P_DIACONSUMOINI,
                            :P_DIACONSUMOFIN,
                            :P_IDDIACONSINIANT,
                            :P_IDDIACONSFINANT,
                            :P_NRORG
                        )";
            
            $params = array(
                "P_CDPERIENTR"   => $row['CDPERIENTR'],
                "P_DIENTREGA"    => $row['DIENTREGA'],
                "P_DIACONSUMOINI" => $diaConsumo['DIACONSUMOINI'],
                "P_DIACONSUMOFIN" => $diaConsumo['DIACONSUMOFIN'],
                "P_IDDIACONSINIANT" => $row['IDDIACONSINIANT'],
                "P_IDDIACONSFINANT" => $row['IDDIACONSFINANT'],
                "P_NRORG"        => $this->environment->getNrorg(),
            );

            $this->supUtilities->crud($query, $params);
        } catch (\Exception $e){
            throw $e; 
        }
    }
    
    public function deleteDiaConsumo($row){
        try{
            $query = "DELETE FROM DIASCONSUMO 
                        WHERE 
                          CDPERIENTR = :CDPERIENTR AND
                          DIENTREGA = :DIENTREGA";

            $param = array(
                "CDPERIENTR" => $row['CDPERIENTR'],
                "DIENTREGA"  => $row['DIENTREGA'],
            );

            $this->supUtilities->crud($query, $param);
        } catch (\Exception $e){
            throw $e; 
        }
    }
    
    public function deleteDiaEntrega($row){
        try{
            $query = "DELETE FROM DIASENTR 
                        WHERE 
                          CDPERIENTR = :CDPERIENTR AND
                          DIENTREGA = :DIENTREGA";

            $param = array(
                "CDPERIENTR" => $row['CDPERIENTR'],
                "DIENTREGA" => $row['DIENTREGA'],
            );

            $this->supUtilities->crud($query, $param);
        } catch (\Exception $e){
            throw $e; 
        }
    }
    
    public function getPeriodicidade($row){
        try{
            $query = "SELECT CDPERIENTR, IDGRAVADTCONSUM FROM PERIENTR WHERE CDPERIENTR = :CDPERIENTR AND NRORG = :NRORG";
            
            $params = array(
                "CDPERIENTR" => $row['CDPERIENTR'],
                "NRORG"      => $this->environment->getNrorg(),
            );

            return $this->supUtilities->crud($query, $params);
        } catch (\Exception $e){
            throw $e; 
        }
    }
    
    public function getDiaEntrega($row){
        try{
            $query = "SELECT 
                            CDPERIENTR, 
                            DIENTREGA 
                        FROM 
                            DIASENTR 
                        WHERE 
                            CDPERIENTR = :CDPERIENTR AND 
                            DIENTREGA = :DIENTREGA AND 
                            NRORG = :NRORG";
            
            $params = array(
                "CDPERIENTR" => $row['CDPERIENTR'],
                "DIENTREGA"  => $row['DIENTREGA'],
                "NRORG"      => $this->environment->getNrorg(),
            );

            return $this->supUtilities->crud($query, $params);
        } catch (\Exception $e){
            throw $e; 
        }
    }
    
    public function insertPeriodicidade($row){
        try{
            $query = "INSERT INTO PERIENTR (
                            CDPERIENTR,
                            NMPERIENTR,
                            IDDIANUTIL,
                            IDTIPODIA,
                            IDDNULIMSEGP,
                            IDGRAVADTCONSUM,
                            NRORG
                        ) VALUES (
                            :CDPERIENTR,
                            :NMPERIENTR,
                            :IDDIANUTIL,
                            :IDTIPODIA,
                            :IDDNULIMSEGP,
                            :IDGRAVADTCONSUM,
                            :NRORG
                        )";
            
            $params = array(
                "CDPERIENTR"   => $row['CDPERIENTR'],
                "NMPERIENTR"   => $row['NMPERIENTR'],
                "IDDIANUTIL"   => $row['IDDIANUTIL'],
                "IDTIPODIA"    => $row['IDTIPODIA'],
                "IDDNULIMSEGP" => $row['IDDNULIMSEGP'],
                "IDGRAVADTCONSUM" => $row['IDGRAVADTCONSUM'],
                "NRORG"        => $this->environment->getNrorg(),
            );

            $this->supUtilities->crud($query, $params);
        } catch (\Exception $e){
            throw $e; 
        }
    }
    
    public function updatePeriodicidade($row){
        try{
            $query = "UPDATE PERIENTR
                        SET
                          CDPERIENTR    = :CDPERIENTR,
                          NMPERIENTR    = :NMPERIENTR,
                          IDDIANUTIL    = :IDDIANUTIL,
                          IDTIPODIA     = :IDTIPODIA,
                          IDDNULIMSEGP  = :IDDNULIMSEGP,
                          IDGRAVADTCONSUM  = :IDGRAVADTCONSUM
                        WHERE
                          CDPERIENTR = :CDPERIENTR";
            
            $params = array(
                "CDPERIENTR"      => $row['CDPERIENTR'],
                "NMPERIENTR"      => $row['NMPERIENTR'],
                "IDDIANUTIL"      => $row['IDDIANUTIL'],
                "IDTIPODIA"       => $row['IDTIPODIA'],
                "IDDNULIMSEGP"    => $row['IDDNULIMSEGP'],
                "IDGRAVADTCONSUM" => $row['IDGRAVADTCONSUM']
            );

            $this->supUtilities->crud($query, $params);
        } catch (\Exception $e){
            throw $e; 
        }
    }
    
    public function deleteAllDiasConsumo($row){
        try{
            $query = "DELETE FROM DIASCONSUMO 
                        WHERE 
                          CDPERIENTR = :CDPERIENTR";

            $param = array(
                "CDPERIENTR" => $row['CDPERIENTR']
            );

            $this->supUtilities->crud($query, $param);
        } catch (\Exception $e){
            throw $e; 
        }
    }
}