<?php
namespace Modules\Relatorio\Controllers;

use Util\SupUtilities;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;


class Sup00900MixDeFornecedorController extends \Teknisa\GER\Controllers\TeknisaCrud {

    protected $supUtilities;
    protected $environment;
    protected $dataSourceName;

    public function __construct($crudService, $parameterBag, SupUtilities $supUtilities, $environment) 
    {
        parent::__construct($crudService, $parameterBag);
        $this->supUtilities = $supUtilities;
        $this->environment  = $environment;
    }

    private function getParamgeral() 
    {
        try {
            return $this->crudService->getFilteredDataSet("paramgeral", [])->getRows();
        } catch (\Exception $e) {
            throw new \Exception($e->getMessage());
        }
    }

    private function getIdsisdos()
    {
        try {
            $paramgeral = $this->getParamgeral();
            
            if(!isset($paramgeral)) {
                throw new \Exception('PARAMGERAL_NOT_REGISTERED');
            }
            
            return $paramgeral[0]['IDSISDOS'];
        } catch (\Exception $e) {
            throw new \Exception($e->getMessage());
        }
    }

    private function getCentral()
    {
        try {
            $data = $this->supUtilities->getCentralCompras($this->environment->getCdFilial());
            if(!$data) {
                throw new \Exception('CDFILCENTCMP_NOT_REGISTERED');
            }
            
            return $data['CDFILCENTCMP'];
        } catch (\Exception $e) {
            throw new \Exception($e->getMessage());
        }
    }

    private function getParasupri()
    {
        try {
            $conditions = array(
                array(
                    'columnName' => 'CDFILIAL',
                    'operator' => '=',
                    "value" => self::getCentral()
                )
            );

            $parasupri = $this->crudService->getFilteredDataSet("parasupri", $conditions)->getRows();
            if(!isset($parasupri)) {
                throw new \Exception('PARASUPRI_NOT_REGISTERED');
            }        
            
            return $parasupri;
        } catch (\Exception $e) {
            throw new \Exception($e->getMessage());
        }
    }

    public function getData(DTO\Request\Filter $request, DTO\Response $response)
    {
        try {
            $conditions = $request->getFilterCriteria()->getConditions();
            $filterCriteria = $request->getFilterCriteria();
            
            $idsisdos = self::getIdsisdos();
            $parasupri = self::getParasupri();
            $central = $parasupri[0]['CDFILIAL'];
            $idconsprsol = $parasupri[0]['IDCONSPRSOL'];            
            
            $filterCriteria->addCondition("P_CDFILCENTCMP", $central);

            if($idsisdos === '3') {
                $this->dataSourceName = 'sup00900GRConsProdSolData';
            } else {
                if($idconsprsol === 'S') {
                    $this->dataSourceName = 'sup00900ConsProdSolData';
                } else {
                    $this->dataSourceName = 'sup00900NConsProdSolData';
                }
            }
            
            parent::find($request, $response);
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
}