<?php
namespace Folha\Logic\ESocial\Eventos\Data;

/**
 * Classe provedora do datasource utilizado para a geracao do evento S-2206 - Alteração de Contrato de Trabalho
 *
 * @package Folha\Logic\ESocial\Eventos\Data
 * @author felipesantos
 **/
class S2206
{

    /**
     * Retorna os dados que serao utilizados para a geracao do(s) arquivo(s) do evento S-2206, Alteração de Contrato de Trabalho.
     *
     * @param $dsordem                 Define as possíveis formas de filtro utilizadas pela tela de envio de eventos  
     *                                 do e-Social. Pode ser ALFABETICA, MATRICULA, DATA_ADMISSAO e ESTRUTURA. Para este
     *                                 evento, em especial, somente o filtro por ESTRUTURA poderá será relevante.
     * @param $limiteInferior          Limite inferior do filtro aplicado. O significado dos dados trazidos neste campo
     *                                 deverao variar, conforme o parametro dsordem.
     * @param $limiteSuperior          Limite superior do filtro apliceado. O significado dos dados trazidos neste campo
     *                                 deverao variar, conforme o parametro dsordem.
     * @param $inicioPeriodo           Inicio do intervalo que deverá ter os eventos gerados. Somente será utilizado se
     *                                 o parametro "$utilizaIntervaloDeDatas" for igual a "true". 
     * @param $fimPeriodo              Final do intervalo que deverá ter os eventos gerados. Somente será utilizado se
     *                                 o parametro "$utilizaIntervaloDeDatas" for igual a "true".
     * @param $utilizaIntervaloDeDatas Verifica se o dataset deve ser filtrado pelos campos de intervalo da tela de  
     *                                 envio de eventos e-Social, ou se devem enviados os arquivos alterados depois do 
     *                                 ultimo envio.
     * @param $nrorg                   Nrorg.
     * @param $versaoHRM               Versao do sistema HRM utilizado para a geracao dos relatorios.
     *
     * @return array
     * @author felipesantos
     **/
    public static function getDataSource($dsordem, $limiteInferior, $limiteSuperior, $inicioPeriodo, $fimPeriodo,
                                         $utilizaIntervaloDeDatas, $nrorg, $versaoHRM, $versaoEsocial, $tpAmbiente, $indRetificacao, $nrRecibo)
    {
        $S2206 = \Folha\Repositories\GpeEsocialRegistro::dataSetEsocial_S2206(
            $dsordem, $limiteInferior, $limiteSuperior, $inicioPeriodo, $fimPeriodo,
            $utilizaIntervaloDeDatas, $nrorg, $versaoHRM, $versaoEsocial, $tpAmbiente, $indRetificacao, $nrRecibo
        );

        foreach ($S2206 as &$row) {
            /*Aqui é definida a forma de regime de trabalho - Por padrão está definido como celetista*/
            //@todo Analisar forma de gerar os dois tipos de regime: Celetista e Estatuário
            $row['INFOCELETISTA'] = '1';

            /*Aqui é definido o local de trabalho - Por padrão está definido como trabalhador não doméstico*/
            //@todo Analisar local de trabalho para trabalhadores domésticos
            $row['LOCALTRABGERAL'] = '1';

            /*Aqui é definido se há informações do horário de trabalho*/
            if (isset($row['QTDHRSSEM']) or isset($row['TPJORNADA'])) {
                $row['HORCONTRATUAL'] = '1';
            }

            /*Aqui são geradas as informações diárias do horário contratual do empregado*/
            $horarios = \Folha\Repositories\GpeEsocialRegistro::s2100_horario($row['NRESCALATRABM'], $nrorg);
            $contDias = 0;
            foreach ($horarios as &$dia) {
                $row['HORARIO'][$contDias] =
                    array(
                        "_EVTADMISSAO_VINCULO_INFOCONTRATO_HORCONTRATUAL_HORARIO_DIA" => $dia['DIA'],
                        "_EVTADMISSAO_VINCULO_INFOCONTRATO_HORCONTRATUAL_HORARIO_CODHORCONTRAT" => $dia['CODHORCONTRAT']);
                $contDias++;
            }

            /*Aqui é verificado se é filiado à algum sindicato*/
            if (isset($row['CNPJSINDTRAB'])) {
                $row['FILIACAOSINDICAL'] = '1';
            }
        }

        return $S2206;
    }

}